---
search:
  exclude: true
---
# リリースプロセス/変更履歴

このプロジェクトは、`0.Y.Z` の形式を用いた、やや調整したセマンティックバージョニングに従います。先頭の `0` は、SDK が依然として急速に進化していることを示します。各コンポーネントの増分は以下のとおりです。

## マイナー (`Y`) バージョン

ベータと明示されていない公開インターフェースに対する**破壊的変更**がある場合、マイナー バージョン `Y` を上げます。たとえば、`0.0.x` から `0.1.x` への更新には破壊的変更が含まれる可能性があります。

破壊的変更を避けたい場合は、プロジェクトで `0.0.x` バージョンに固定することをおすすめします。

## パッチ (`Z`) バージョン

破壊的でない変更については `Z` を増分します。

-   バグ修正
-   新機能
-   非公開インターフェースの変更
-   ベータ機能の更新

## 破壊的変更の変更履歴

### 0.2.0

このバージョンでは、これまで引数として `Agent` を受け取っていたいくつかの箇所が、代わりに `AgentBase` を引数として受け取るようになりました。たとえば、MCP サーバーでの `list_tools()` 呼び出しです。これは型に関する変更のみであり、引き続き `Agent` オブジェクトを受け取ります。更新の際は、`Agent` を `AgentBase` に置き換えて型エラーを修正してください。

### 0.1.0

このバージョンでは、[`MCPServer.list_tools()`][agents.mcp.server.MCPServer] に新しいパラメーター `run_context` と `agent` が追加されました。`MCPServer` をサブクラス化しているすべてのクラスに、これらのパラメーターを追加する必要があります。